import java.io.File
import org.scalajs.sbtplugin.ScalaJSPlugin.autoImport._

val Organization = "openmole"
val Name = "gate"
val Version = "0.1.0-SNAPSHOT"
val ScalaVersion = "2.12.4"
val scalatraVersion = "2.6.2"
val jettyVersion = "9.4.8.v20171121"
val json4sVersion = "3.5.2"
val scalatagsVersion = "0.6.5"
val autowireVersion = "0.2.6"
val upickleVersion = "0.4.4"
val rxVersion = "0.3.2"
val scaladgetVersion = "0.9.5"
val scalajsDomVersion = "0.9.3"
val jqueryVersion = "3.2.1"
val hasherVersion = "1.2.0"
val betterFilesVersion = "3.4.0"
val mongoDBVersion = "3.1.1"
val scoptVersion = "3.7.0"

val Resolvers = Seq(Resolver.sonatypeRepo("snapshots"),
  Resolver.sonatypeRepo("staging"),
  "Typesafe repository" at "http://repo.typesafe.com/typesafe/releases/"
)

lazy val shared = project.in(file("shared")).settings(
  scalaVersion := ScalaVersion
)

lazy val client = project.in(file("client")) settings(
  organization := Organization,
  version := Version,
  scalaVersion := ScalaVersion,
  skip in packageJSDependencies := false,
  libraryDependencies ++= Seq(
    "com.lihaoyi" %%% "autowire" % autowireVersion,
    "com.lihaoyi" %%% "upickle" % upickleVersion,
    "com.lihaoyi" %%% "scalatags" % scalatagsVersion,
    "com.lihaoyi" %%% "scalarx" % rxVersion,
    "fr.iscpif" %%% "scaladget" % scaladgetVersion,
    "org.scala-js" %%% "scalajs-dom" % scalajsDomVersion,
    "org.json4s" %% "json4s-jackson" % json4sVersion
  )
) dependsOn (shared) enablePlugins (ScalaJSPlugin)

lazy val server = project.in(file("server")) settings(
  organization := Organization,
  name := Name,
  version := Version,
  scalaVersion := ScalaVersion,
  libraryDependencies ++= Seq(
    "org.mongodb" %% "casbah" % mongoDBVersion,
    "com.roundeights" %% "hasher" % hasherVersion,
    "com.github.pathikrit" %% "better-files" % betterFilesVersion,
    "com.lihaoyi" %% "autowire" % autowireVersion,
    "com.lihaoyi" %% "upickle" % upickleVersion,
    "com.lihaoyi" %% "scalatags" % scalatagsVersion,
    "org.scalatra" %% "scalatra" % scalatraVersion,
    "org.scalatra" %% "scalatra-auth" % scalatraVersion,
    "ch.qos.logback" % "logback-classic" % "1.1.3" % "runtime",
    "javax.servlet" % "javax.servlet-api" % "3.1.0" % "provided",
    "org.eclipse.jetty" % "jetty-webapp" % jettyVersion,
    "org.eclipse.jetty" % "jetty-server" % jettyVersion,
    "org.scala-lang" % "scala-compiler" % scalaVersion.value,
    "org.scala-lang" % "scala-reflect" % scalaVersion.value
  )
) dependsOn (shared) enablePlugins (JettyPlugin)


lazy val lab = project.in(file("lab")) settings(
  scalaVersion := ScalaVersion,
  fork := true,
libraryDependencies ++= Seq(
    "com.github.scopt" %% "scopt" % scoptVersion
)
  //  organization := Organization,
  //  name := Name,
  //  version := Version,
  //  scalaVersion := ScalaVersion
) dependsOn (server)


lazy val go = taskKey[Unit]("go")

lazy val bootstrap = project.in(file("target/bootstrap")) settings(
  version := Version,
  scalaVersion := ScalaVersion,
  go := {
    val clientJS = (fullOptJS in client in Compile).value

    val serverReources = (resourceDirectory in server in Compile).value / "webapp"
    val webappTarget = (classDirectory in server in Compile).value / "webapp"

    IO.copyDirectory(serverReources, webappTarget)
    IO.copyFile(clientJS.data, webappTarget / "js/gate.js")
  }
) dependsOn(client, server)

